==> babel-0.0.3.tgz: package/src/__tests__/ts/defaults.js <==
/*

Copyright (C) 2016,2017 wallzero 2016,2017

This program is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software Foundation,
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this
program. If not, see <http://www.gnu.org/licenses/>.

*/

/*
  eslint-disable
  import/unambiguous,
  import/no-commonjs,
  import/no-dynamic-require,
  global-require,
  no-undef
*/

const {babel} = require('@digest/scripts/src/config.js');
const scripts = require('../scripts.json');

const NOT_PLUGINS = [].concat(
  scripts.jsx.plugins,
  scripts.jsx.production.plugins,
  scripts.jsx.development.plugins
);
const NOT_PRESETS = [].concat(
  scripts.jsx.presets,
  scripts.jsx.production.presets,
  scripts.jsx.development.presets
);

let babelConfig;
let plugins;
let presets;

beforeAll(() => {
  process.env = {}; // eslint-disable-line no-process-env

  if (babel) {
    babelConfig = require(babel)();
  }

  plugins = babelConfig.plugins.map((plugin) => {
    return Object.prototype.toString.call(plugin) === '[object String]' ?
      plugin :
      plugin[0];
  });
  presets = babelConfig.options.presets.map((preset) => {
    return Array.isArray(preset) ? preset[0] : preset;
  });
});

describe('Webpack settings for Typescript', () => {
  test('not plugins', () => {
    expect(plugins).not.toEqual(expect.arrayContaining(NOT_PLUGINS));
  });

  test('not presets', () => {
    expect(presets).not.toEqual(expect.arrayContaining(NOT_PRESETS));
  });
});

==> babel-0.0.4.tgz: package/src/__tests__/ts/defaults.js <==
/*

Copyright (C) 2016,2017 wallzero 2016,2017

This program is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software Foundation,
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this
program. If not, see <http://www.gnu.org/licenses/>.

*/

/*
  eslint-disable
  import/unambiguous,
  import/no-commonjs,
  import/no-dynamic-require,
  global-require,
  no-undef
*/

const {babel} = require('@digest/scripts/src/config.js');
const scripts = require('../scripts.json');

const NOT_PLUGINS = [].concat(
  scripts.jsx.plugins,
  scripts.jsx.production.plugins,
  scripts.jsx.development.plugins
);
const NOT_PRESETS = [].concat(
  scripts.jsx.presets,
  scripts.jsx.production.presets,
  scripts.jsx.development.presets
);

let babelConfig;
let plugins;
let presets;

beforeAll(() => {
  jest.resetModules();
  process.env = {}; // eslint-disable-line no-process-env

  if (babel) {
    babelConfig = require(babel)();
  }

  plugins = babelConfig.plugins.map((plugin) => {
    return Object.prototype.toString.call(plugin) === '[object String]' ?
      plugin :
      plugin[0];
  });
  presets = babelConfig.presets.map((preset) => {
    return Array.isArray(preset) ? preset[0] : preset;
  });
});

describe('Webpack settings for Typescript', () => {
  test('not plugins', () => {
    expect(plugins).not.toEqual(expect.arrayContaining(NOT_PLUGINS));
  });

  test('not presets', () => {
    expect(presets).not.toEqual(expect.arrayContaining(NOT_PRESETS));
  });
});
